@@ -71,35 +71,35 @@ param = do
   v ← paramValue n'
   return (n', v)
 
-link ∷ Parser Link
+link ∷ (IsURI uri) ⇒ Parser (Link uri)
 link = do
   charWS '<'
   linkText ← takeWhile1 $ allConditions [(/= '>'), not . isSpace]
   charWS '>'
   params ← many' $ param
   skipSpace
-  case parseURIReference $ unpack linkText of
-    Just u → return $ Link u params
-    Nothing → fail "Couldn't parse the URI"
+  case uriFromText linkText of
+    Right u → return $ Link u params
+    Left e → fail $ "Couldn't parse the URI " ++ show linkText ++ if e == "" then "" else ": " ++ e
 
 -- | The Attoparsec parser for the Link header.
-linkHeader ∷ Parser [Link]
+linkHeader ∷ (IsURI uri) ⇒ Parser [Link uri]
 linkHeader = link `sepBy'` (char ',')
 
 -- | Parses a Link header, returns an Either, where Left is the Attoparsec
 -- error string (probably not a useful one).
-parseLinkHeader' ∷ Text → Either String [Link]
+parseLinkHeader' ∷ (IsURI uri) ⇒ Text → Either String [Link uri]
 parseLinkHeader' = parseOnly linkHeader
 
 -- | Parses a Link header, returns a Maybe.
-parseLinkHeader ∷ Text → Maybe [Link]
+parseLinkHeader ∷ (IsURI uri) ⇒ Text → Maybe [Link uri]
 parseLinkHeader = hush . parseLinkHeader'
 
 -- | Parses a Link header, returns an Either, where Left is the Attoparsec
 -- error string (probably not a useful one).
-parseLinkHeaderBS' ∷ ByteString → Either String [Link]
+parseLinkHeaderBS' ∷ (IsURI uri) ⇒ ByteString → Either String [Link uri]
 parseLinkHeaderBS' = parseLinkHeader' . decodeUtf8
 
 -- | Parses a Link header, returns a Maybe.
-parseLinkHeaderBS ∷ ByteString → Maybe [Link]
+parseLinkHeaderBS ∷ (IsURI uri) ⇒ ByteString → Maybe [Link uri]
 parseLinkHeaderBS = parseLinkHeader . decodeUtf8
